@@ -25,7 +25,7 @@ Created on Nov 10, 2010
 
 # pylint: disable-all
 
-from pyocci import registry
+from pyocci import registry, service
 from pyocci.examples.vm_skeleton import Compute, Network, IPNetworking, Storage, \
     NetworkInterface, StorageLink
 from pyocci.rendering_parsers import TextPlainRendering, TextHeaderRendering, \
@@ -52,6 +52,8 @@ class MyService():
 
     application = None
 
+    service.AUTHENTICATION = True
+
     def __init__(self):
         settings = {
                     "cookie_secret": "61oETzKXQAGaYdkL5gEmGeJJFuYh7EQnp2XdTP1o/Vo=",
@@ -70,7 +72,7 @@ class MyService():
         Start a OCCI comliant service.
         '''
         http_server = tornado.httpserver.HTTPServer(self.application)
-        http_server.listen(8080)
+        http_server.listen(8888)
         tornado.ioloop.IOLoop.instance().start()
 
 if __name__ == '__main__':
